===============================
Tool Grid Widget (``toolgrid``)
===============================

.. automodule:: Orange.OrangeCanvas.gui.toolgrid

.. autoclass:: Orange.OrangeCanvas.gui.toolgrid.ToolGrid
   :members:
   :member-order: bysource
   :show-inheritance:

   .. autoattribute:: actionTriggered(QAction)

      Signal emitted when an action is triggered.

   .. autoattribute:: actionHovered(QAction)

      Signal emitted when an action is hovered.

